@@ -1,8 +1,4 @@
-if [ -x /usr/bin/gtk-update-icon-cache.exe ]
-then
-    /usr/bin/gtk-update-icon-cache --force /usr/share/icons/hicolor
-fi
-
+rm -f /usr/share/icons/hicolor/icon-theme.cache
 if ! /usr/bin/gtk-query-immodules-2.0 --update-cache
 then
 /usr/bin/mkdir -p /etc/gtk-2.0
@@ -12,5 +8,3 @@ fi
 
 /usr/bin/gtk-query-immodules-3.0 --update-cache
 
-/usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas
-
